@@ -1,6 +1,6 @@
 package Number::Closest;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moose;
 
@@ -10,7 +10,7 @@ has 'numbers'  => (isa => 'ArrayRef[Num]', is => 'rw', required => 1);
 sub analyze {
     my($self)=@_;
 
-    my @dist = sort { $a->[1] <=> $b->[1] } map { [$_, abs($_ - $self->number)] } @{$self->numbers} ;
+    my @dist = sort { $a->[1] <=> $b->[1] } map { [$_, abs($_ - $self->number)] } sort {$a <=> $b} @{$self->numbers};
 
     \@dist
 }
